package com.ynet.life.platform.action;

import com.ynet.gene.comm.http.HttpResource;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.HttpCommunicationException;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.util.PropertiesFile;
import edu.emory.mathcs.backport.java.util.Arrays;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.Vector;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_platform_action.jar:com/ynet/life/platform/action/HttpCommToMsgAction.class */
public class HttpCommToMsgAction extends LifeAction {
    private static final String FIELD_SEPERATOR = "||";
    public static final boolean MASK_PASSWORD = true;
    public static final String MASK_BEGIN_TAG = "<password>";
    public static final String MASK_END_TAG = "</password>";
    public static final String MASK_CONTENT = "<password>****</password>";
    private static final int DEFAULT_TIMEOUT = 60000;
    private static final int REQUEST_LENGTH = 8;
    private static final String ERROR_CODE_PACK = "EBLN0010";
    private static final String ERROR_CODE_POOL = "EBLN0011";
    private static final String ERROR_CODE_LOSEDATA = "EBLN0012";
    private static final String ERROR_CODE_TIMEOUT = "EBLN0013";
    private static final String ERROR_CODE_UNPACK = "EBLN0014";
    private static final String ERROR_CODE_GATEWAY = "EBLN0015";
    private static final String returnFlag = "tempuri.org";
    private String hostCode;
    private List sendFormatName = new ArrayList();
    private String receiveFormatName;
    private String recMsgDataName;
    public static final String FIELD_HOST_RETURN_CODE = "smsReturnCode";
    public static final String FIELD_HOST_ERROR_MESSAGE = "hostErrorMessage";

    public String execute(Context context) throws GENEException {
        String readLocalFile = LifeStandard.getBankSettingsValue("readLocalFile");
        if ("true".equals(readLocalFile)) {
            return localMeg(context);
        }
        try {
            HttpResource service = (HttpResource) context.getService("HttpConnectionPool");
            System.out.println("==================================================" + service.getId());
            if (service == null) {
                throw new TranFailException(ERROR_CODE_POOL, "无法获取通讯服务");
            }
            try {
                String sendMessage = String.valueOf(prepareData(context)) + getSendMsg(context);
                print("金融办请求报文：\n".concat(String.valueOf(sendMessage)));
                try {
                    String receivedMessage = service.sendAndWait(sendMessage, DEFAULT_TIMEOUT);
                    if (receivedMessage == null) {
                        throw new TranFailException(ERROR_CODE_LOSEDATA, "返回报文长度异常");
                    }
                    print("网关返回报文：\n".concat(String.valueOf(receivedMessage)));
                    try {
                        int resultFlagPos = receivedMessage.indexOf(returnFlag) + 14;
                        int resultEndPos = receivedMessage.indexOf("</", resultFlagPos);
                        String returnCode = receivedMessage.substring(resultFlagPos, resultEndPos);
                        context.put("smsReturnCode", returnCode);
                    } catch (Exception unused) {
                        context.put("smsReturnCode", "EBLN0000");
                    }
                    try {
                        if (this.recMsgDataName != null) {
                            context.setDataValue(this.recMsgDataName, receivedMessage);
                        }
                        try {
                            dealResult(context);
                            return "0";
                        } catch (TranFailException te) {
                            Trace.logError("LifeAction", te.getShowMessage(), te);
                            context.put("GENEException", te);
                            throw te;
                        }
                    } catch (Exception e) {
                        throw new TranFailException(ERROR_CODE_UNPACK, e);
                    }
                } catch (GENEException ex) {
                    throw new TranFailException(ERROR_CODE_TIMEOUT, "网关通信超时", ex);
                }
            } catch (GENEException ex2) {
                throw new TranFailException(ERROR_CODE_PACK, "准备报头数据出错", ex2);
            }
        } catch (TranFailException te2) {
            Trace.logError("LifeAction", te2.getShowMessage(), te2);
            context.put("GENEException", te2);
            throw new HttpCommunicationException(te2);
        }
    }

    private String localMeg(Context context) throws TranFailException {
        try {
            String sendMessage = getSendMsg(context);
            print("----上送报文----\n" + sendMessage + "\n");
            return "0";
        } catch (TranFailException ex) {
            throw new TranFailException(ERROR_CODE_PACK, "发送报文格式化失败", ex);
        }
    }

    public String getSendMsg(Context context) throws TranFailException {
        int dateSize = this.sendFormatName.size();
        StringBuffer resultStr = new StringBuffer();
        Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/system.properties");
        String whitePhoneMode = bankDBSourceProperties.getProperty("whitePhoneMode");
        String whitePhoneList = bankDBSourceProperties.getProperty("whitePhoneList");
        for (int i = 0; i < dateSize; i++) {
            String dataStr = (String) this.sendFormatName.get(i);
            StringBuilder phoneCon = new StringBuilder();
            try {
                String dataFieldValue = (String) context.getDataValue(dataStr);
                if (StringUtils.equals("pszMsg", dataStr)) {
                    dataFieldValue = URLEncoder.encode(dataFieldValue, "UTF-8");
                }
                if (StringUtils.equals("pszMobis", dataStr)) {
                    try {
                        if ("on".equals(whitePhoneMode)) {
                            String phonesTmp = dataFieldValue;
                            Iterator<String> itor = new ArrayList(Arrays.asList(phonesTmp.split(","))).iterator();
                            while (itor.hasNext()) {
                                String nextPhone = itor.next();
                                if (String.valueOf(whitePhoneList).indexOf(nextPhone) == -1) {
                                    phoneCon.append("12345678901");
                                } else {
                                    phoneCon.append(nextPhone);
                                }
                                if (itor.hasNext()) {
                                    phoneCon.append(",");
                                }
                            }
                            dataFieldValue = phoneCon.toString();
                        } else {
                            dataFieldValue = (String) context.getDataValue(dataStr);
                            if (StringUtils.equals("pszMsg", dataStr)) {
                                dataFieldValue = URLEncoder.encode(dataFieldValue, "UTF-8");
                            }
                        }
                    } catch (Exception ex) {
                        throw new TranFailException(ERROR_CODE_PACK, String.valueOf("") + "在rootContext未定义", ex);
                    }
                }
                resultStr.append("&").append(dataStr).append("=").append(dataFieldValue);
            } catch (Exception ex2) {
                throw new TranFailException(ERROR_CODE_PACK, String.valueOf(dataStr) + "在rootContext未定义", ex2);
            }
        }
        return resultStr.toString();
    }

    protected List getReqHeadParams() {
        List params = new ArrayList();
        params.add("$gatewayData.gwPkgType,2");
        params.add("$gatewayData.gwTrxCode,8");
        params.add("$gatewayData.gwMsgType,1");
        params.add("$gatewayData.gwReqTime,14");
        params.add("$gatewayData.gwFlwNo,8");
        params.add("$gatewayData.gwReqChannel,2");
        params.add("$gatewayData.gwBrchETellerNo,8");
        params.add("$gatewayData.gwRsCode,6");
        params.add("$gatewayData.gwReserveMe,32");
        params.add("$gatewayData.gwRsResultFlag,1");
        params.add("$gatewayData.hBrchNo,3");
        params.add("$gatewayData.hBrchClrNo,7");
        params.add("$gatewayData.hBrchETellerNo,8");
        return params;
    }

    protected String getGWHead(Context context, List headParams) throws GENEException {
        StringBuffer temp;
        StringBuffer result = new StringBuffer();
        if (headParams != null) {
            for (int i = 0; i < headParams.size(); i++) {
                String param = (String) headParams.get(i);
                boolean isField = param.startsWith("$");
                int idx = param.indexOf(",");
                int len = Integer.parseInt(param.substring(idx + 1).trim());
                if (isField) {
                    temp = new StringBuffer((String) context.getDataValue(param.substring(1, idx)));
                } else {
                    temp = new StringBuffer(param.substring(0, idx));
                }
                if (temp.length() < len) {
                    for (int k = temp.length(); k < len; k++) {
                        temp.append(" ");
                    }
                    result.append(temp);
                } else if (temp.length() > len) {
                    result.append(temp.substring(0, len));
                } else {
                    result.append(temp);
                }
            }
        }
        return result.toString();
    }

    protected String prepareData(Context context) throws GENEException {
        String userId = LifeStandard.getBankSettingsValue("smsUserId");
        String passowrd = LifeStandard.getBankSettingsValue("smsPasword");
        StringBuffer str = new StringBuffer();
        str.append("userId").append("=").append(userId).append("&").append("password").append("=").append(passowrd);
        return str.toString();
    }

    private void dealResult(Context context) throws TranFailException {
        String hostReturnCode = (String) context.get("smsReturnCode");
        if (hostReturnCode == null) {
            throw new TranFailException("EBLN0000", "无法获取交易结果代码smsReturnCode");
        }
        if (hostReturnCode != null && hostReturnCode.length() < 14) {
            String hostErrorMessage = null;
            try {
                hostErrorMessage = (String) context.getDataValue("hostErrorMessage");
            } catch (GENEException ex) {
                Trace.logWarning("LifeAction", ex.getMessage(), ex);
            }
            if (hostErrorMessage == null) {
                LifeErrorInfo error = LifeStandard.getErrorInfo(hostReturnCode);
                if (error == null) {
                    throw new TranFailException(hostReturnCode, "未知的错误代码");
                }
                hostErrorMessage = error.getShowMsg();
            }
            TranFailException ex2 = new TranFailException(hostReturnCode, hostErrorMessage);
            context.put("GENEException", ex2);
            throw ex2;
        }
    }

    private String maskMessage(String message) {
        Vector passVector = getSegmentsStr(LifeStandard.getBankSettingsValue("PasswordFields_Masked"), ",");
        for (int i = 0; i < passVector.size(); i++) {
            String subStr = ((String) passVector.elementAt(i)).trim();
            if (!"".equals(subStr)) {
                String subStr2 = "<" + subStr + ">";
                String subStrEnd = "</" + subStr + ">";
                String mask_content = String.valueOf(subStr2) + "******" + subStrEnd;
                int tagBeginPos = message.indexOf(subStr2);
                if (tagBeginPos >= 0) {
                    int tagEndPos = message.indexOf(subStrEnd) + subStrEnd.length();
                    return String.valueOf(message.substring(0, tagBeginPos)) + mask_content + message.substring(tagEndPos);
                }
            }
        }
        return message;
    }

    private String readLocalFile() {
        InputStreamReader read = null;
        BufferedReader in = null;
        String message = null;
        FileInputStream file = null;
        try {
            try {
                String rootPath = LifeStandard.getRootPath();
                String virtualHostFileName = String.valueOf(rootPath) + "WEB-INF/virtualhost/" + this.hostCode + ".txt";
                File virtualHostFile = new File(virtualHostFileName);
                if (!virtualHostFile.exists()) {
                    Trace.logError("LifeFile", "读取本地文件出错");
                }
                file = new FileInputStream(virtualHostFile);
                read = new InputStreamReader(file);
                in = new BufferedReader(read);
                StringBuffer sb = new StringBuffer();
                while (true) {
                    String line = in.readLine();
                    if (line == null) {
                        break;
                    }
                    sb = sb.append(line);
                }
                message = sb.toString();
                try {
                    in.close();
                    read.close();
                    file.close();
                } catch (IOException unused) {
                }
            } catch (Exception e) {
                Trace.logError("LifeFile", "读取本地文件出错", e);
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException unused2) {
                    }
                }
                if (read != null) {
                    read.close();
                }
                if (file != null) {
                    file.close();
                }
            }
            return message;
        } catch (Throwable th) {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException unused3) {
                    throw th;
                }
            }
            if (read != null) {
                read.close();
            }
            if (file != null) {
                file.close();
            }
            throw th;
        }
    }

    private void print(String message) {
        Trace.logInfo("LifeHTTP", maskMessage(message));
        GENELog.log("LifeHTTP", GENELog.INFO, 0, maskMessage(message));
    }

    public void setHostCode(String hostCode) {
        this.hostCode = hostCode;
    }

    public void setSendFormatName(String sendFormatName) {
        StringTokenizer toke = new StringTokenizer(sendFormatName, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            this.sendFormatName.add(input);
        }
    }

    public void setReceiveFormatName(String receiveFormatName) {
        this.receiveFormatName = receiveFormatName;
    }

    public void setRecMsgDataName(String recMsgDataName) {
        this.recMsgDataName = recMsgDataName;
    }

    private static Vector getSegmentsStr(String str, String token) {
        Vector vocter = new Vector(1);
        StringTokenizer st = new StringTokenizer(str, token);
        while (st.hasMoreTokens()) {
            String des = st.nextToken();
            vocter.addElement(des);
        }
        return vocter;
    }
}
